@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate musical cadence chords
 
-our $VERSION = '0.1103';
+our $VERSION = '0.1104';
 
 use Moo;
 use Music::Chord::Note;
@@ -164,7 +164,7 @@ sub _invert_chord {
         for ( @$chord ) {
             if ( $octave ) {
                 s/-1/$octave/;
-                s/0/++$octave/e;
+                s/0/$octave + 1/e;
             }
             else {
                 s/-1//;
@@ -238,7 +238,7 @@ Music::Cadence - Generate musical cadence chords
 
 =head1 VERSION
 
-version 0.1103
+version 0.1104
 
 =head1 SYNOPSIS
 
